@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
 __author__ = 'jasonxu'
 from cthun_client.config import Config
+from cthun_client.connection import Connection
 from cthun_client.device.ios import Ios
 from cthun_client.device.android import Android
-from cthun_client.connection import Connection
 
 
 class Client:
@@ -27,3 +27,6 @@ class Client:
     def android(self, device_id):
         return self._android(device_id)
 
+    def get_pos(self, device_client):
+        device_client.take_screenshot()
+
